# LiU colors

LiU color definition files for various programs, currently:

- [Inkscape/GIMP](#inkscapegimp)
- [LibreOffice](#libreoffice)
- [Matlab](#matlab)
- [Matplotlib](#matplotlib)

To use the color definitions, see individual instructions below.


## Inkscape/GIMP

### Inkscape
Copy the contents of the `inkscape` folder to your palette folder, which is located at `~/. config/inkscape/palettes` on Linux/OS X or `C:\Users\MY USERNAME\AppData\Roaming\inkscape\palettes` on Windows. If Inkscape is open, restart. Note that `AppData` is a hidden directory, so you may have to type it.

Click on the small arrow to the right of the color bar and select one of the following palettes:
- `LiU Base`: the seven base colors plus black and white
![LiU Base palette example](figures/liubasebar.png "LiU Base palette")
- `LiU Tint`: the seven base colors with 100%, 70%, 50%, 30%, and 20% versions of them plus black and white
![LiU Tint palette example](figures/liutintbar.png "LiU Tint palette")
- `LiU Beamer`: the same colors as in the LiU Beamer LaTeX template plus black and white
![LiU Beamer palette example](figures/liubeamerbar.png "LiU Beamer palette")

### GIMP

The Inkscape palettes are in GIMP format so it is possible to use them for GIMP as well. See https://docs.gimp.org/en/gimp-palette-dialog.html for more information how to import the palettes.

## LibreOffice

Copy the contents of the `libreoffice` folder to your config folder, which is located at `~/.config/libreoffice/4/user/config` on Linux/OS X or `C:\Users\MY USERNAME\AppData\Roaming\LibreOffice\4\user\config` on Windows, where 4 may be a different number based on the first version of LibreOffice that you used. If LibreOffice is open, restart. Note that `AppData` is a hidden directory, so you may have to type it.

You will get an extra option in the color drop down with the name `liubeamer`, see:

![liubeamer palette example](figures/loliubeamer.png "liubeamer palette")

## Matlab

Copy the `matlab` folder and use `addpath` to add it to your Matlab path and, optionally, `savepath` to avoid the need of adding every time you start a new session.

### Commands

- `liucolors`: defines a number of variables with the same names and color definitions as the Beamer LaTeX template, use with the `'color'` optional argument in e.g. `plot`
- `liulines`: color map, primarily for use with the `colororder` command, to get automatic LiU colors on the lines
- `liumap`: tinted color map based on the blue LiU color, primarily to be used with the `colormap` command,  where number of steps and range can be controlled

### Examples

``` matlab
colormap(liumap)
surf(peaks)
```

![liumap example](figures/peaksliumap.png "liumap example")

``` matlab
colororder(liulines)
plot(repmat(1:7, 10, 1) + rand(7,10)')
```

![liulines example](figures/liulinesexample.png "liulines example")

``` matlab
liucolors
plot(sin(linspace(0,2*pi,1000)), 'color', LiUblue)
```

![liucolors example](figures/liucolorexample.png "liucolors example")

## Matplotlib

To install the package:
``` bash
cd matplotlib
python -m pip install .
```

This will install the package `liucolors`.

Use the color map by using the `cmap` optional argument. Available color maps with names are shown below. Think twice, at least, before using `liucontinuouscomplement`.

![liucolors Matplotlib example](figures/matplotlibexample.png "liucolors Matplotlib example")

To use specific colors, there is a dictionary `liubeamercolor` which includes all the colors defined in the LiU Beamer template. An example is

``` python
import matplotlib.pyplot as plt
from liucolors import liubeamercolor

plt.plot([1, 2, 3], [2, 5, 3], color=liubeamercolor["LiUblue"])
```

There is also a SimpleNamespace class `liucolors` which has the colors above as members, without the `LiU`-prefix. This allows easier completion in editors.

``` python
import matplotlib.pyplot as plt
from liucolors import liucolors

plt.plot([1, 2, 3], [2, 5, 3], color=liucolors.blue)
```

Finally, there is a style-file setting up colors and fonts, suitable for inclusion in slides or posters. The following is an example of how to use it:

``` python
import matplotlib.pyplot as plt
import matplotlib as mpl

with mpl.style.context("liucolors.slide"):
    fig, ax = plt.subplots()
    ax.plot([1, 2, 3], [2, 5, 3])
```

Note that the figure size is set to fit on a slide, so for poster use you may want to set a different figure size.
