# -*- coding: utf-8 -*-
"""
LiU Color demo code

Oscar Gustafsson, oscar.gustafsson@liu.se
"""

import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib.ticker import LinearLocator, FormatStrFormatter
import numpy as np

from liucolors import *

colormaplist = [liulines, liucontinuousbase, liucontinuouscomplement,
                liucontinuousblue, liucontinuousturquoise, liucontinuousgreen]

# Make data.
X = np.arange(-5, 5, 0.25)
Y = np.arange(-5, 5, 0.25)
X, Y = np.meshgrid(X, Y)
R = np.sqrt(X**2 + Y**2)
Z = np.sin(R)

fig = plt.figure(figsize=[15,10])
for n, cmap in enumerate(colormaplist):
    # Plot the surface.
    ax = fig.add_subplot(2, 3, n+1, projection='3d')
    surf = ax.plot_surface(X, Y, Z, cmap=cmap,
                           linewidth=0, antialiased=False)
    ax.set_title(cmap.name.lower())
    ax.set_zlim(-1.01, 1.01)
    fig.colorbar(surf,shrink=0.5, aspect=5)
    
fig.tight_layout(pad=2.0)

plt.savefig('matplotlibexample.png')