# -*- coding: utf-8 -*-
"""
LiU Color package for Matplotlib.

Oscar Gustafsson, oscar.gustafsson@liu.se
"""

from types import SimpleNamespace
from matplotlib.colors import ListedColormap, LinearSegmentedColormap

def _liulines():
    cm = [
        [0.        , 0.7254902 , 0.90588235, 1.        ],  # Blue
        [1.        , 0.39215686, 0.25882353, 1.        ],  # Orange
        [0.5372549 , 0.50588235, 0.82745098, 1.        ],  # Purple
        [0.        , 0.81176471, 0.70980392, 1.        ],  # Green
        [0.41568627, 0.49411765, 0.56862745, 1.        ],  # Gray
        [0.99215686, 0.9372549 , 0.36470588, 1.        ],  # Yellow
        [0.09019608, 0.78039216, 0.82352941, 1.        ],  # Turquoise
        ]
    return ListedColormap(cm, name='LiULines')

liulines = _liulines()

def _liucontinuousbase():
    cm = [
        [0.        , 0.7254902 , 0.90588235, 1.        ],  # Blue
        [0.09019608, 0.78039216, 0.82352941, 1.        ],  # Turquoise
        [0.        , 0.81176471, 0.70980392, 1.        ],  # Green
        ]
    return LinearSegmentedColormap.from_list('LiUContinuousBase', cm)

liucontinuousbase = _liucontinuousbase()

def _liucontinuouscomplement():
    cm = [
        [1.        , 0.39215686, 0.25882353, 1.        ],  # Orange
        [0.5372549 , 0.50588235, 0.82745098, 1.        ],  # Purple
        [0.41568627, 0.49411765, 0.56862745, 1.        ],  # Gray
        [0.99215686, 0.9372549 , 0.36470588, 1.        ],  # Yellow
        ]
    return LinearSegmentedColormap.from_list('LiUContinuousComplement', cm)

liucontinuouscomplement = _liucontinuouscomplement()

def _liucontinuousblue():
    cm = [
        [0.        , 0.7254902 , 0.90588235, 1.        ],  # Blue
        [0.9       , 0.97254902, 0.99058824, 1.        ],  # Blue 10%
        ]
    return LinearSegmentedColormap.from_list('LiUContinuousBlue', cm)

liucontinuousblue = _liucontinuousblue()

def _liucontinuousgreen():
    cm = [
        [0.        , 0.81176471, 0.70980392, 1.        ],  # Green
        [0.9       , 0.98117647, 0.97098039, 1.        ],  # Green 10%
        ]
    return LinearSegmentedColormap.from_list('LiUContinuousGreen', cm)

liucontinuousgreen = _liucontinuousgreen()

def _liucontinuousturquoise():
    cm = [
        [0.09019608, 0.78039216, 0.82352941, 1.        ],  # Turquoise
        [0.90901961, 0.97803922, 0.98235294, 1.        ],  # Turquoise 10%
        ]
    return LinearSegmentedColormap.from_list('LiUContinuousTurquoise', cm)

liucontinuousturquoise = _liucontinuousturquoise()

def _liubeamercolor():
    c = { "LiUblue": "#00b9e7",
          "LiUblue2": "#5bcaec",
          "LiUblue3": "#8fd7f1",
          "LiUblue4": "#bde6f6",
          "LiUblue5": "#d2eef9",
          "LiUturquoise": "#17c7d2",
          "LiUturquoise2": "#65cfd8",
          "LiUturquoise3": "#96dae1",
          "LiUturquoise4": "#c2e7ec",
          "LiUturquoise5": "#d7eff2",
          "LiUgreen": "#00cfb5",
          "LiUgreen2": "#56d6c0",
          "LiUgreen3": "#8fdfcf",
          "LiUgreen4": "#bfebe1",
          "LiUgreen5": "#d5f1eb",
          "LiUorange": "#ff6442",
          "LiUorange3": "#ffa49a",
          "LiUorange5": "#ffdcd8",
          "LiUpurple": "#8981d3",
          "LiUpurple3": "#b7b4e1",
          "LiUpurple5": "#e2e0f2",
          "LiUyellow": "#fdef5d",
          "LiUyellow3": "#fef4a5",
          "LiUyellow5": "#fefadc",
          "LiUgray": "#6a7e91",
          "LiUgray3": "#aab2bb",
          "LiUgray5": "#dde0e3",
          "LiUblue0": "#0099c6",
          "LiUturquoise0": "#009ca6",
          "LiUgreen0": "#3ba890",
          "LiUhomepage": "#54d8e0"
          }
    return c

liubeamercolor = _liubeamercolor()

liucolors = SimpleNamespace(**{v[3:] : k for v, k in liubeamercolor.items()})
